==> scipion-em-imod-3.0.1.tar.gz: scipion-em-imod-3.0.1/imod/protocols/__init__.py <==
# **************************************************************************
# *
# * Authors:     J.M. De la Rosa Trevin (delarosatrevin@scilifelab.se) [1]
# *              Federico P. de Isidro Gomez (fp.deisidro@cnb.csi.es) [1]
# *
# * [1] SciLifeLab, Stockholm University
# * [2] Centro Nacional de Biotecnologia, CSIC, Spain
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************

from .protocol_etomo import ProtImodEtomo
from .protocol_auto3d import ProtImodAuto3D
from .protocol_xCorrPrealignment import ProtImodXcorrPrealignment
from .protocol_fiducialAlignment import ProtImodFiducialAlignment
from .protocol_tomoReconstruction import ProtImodTomoReconstruction
from .protocol_applyTransformationMatrix import ProtImodApplyTransformationMatrix
from .protocol_tsNormalization import ProtImodTSNormalization
from .protocol_tomoNormalization import ProtImodTomoNormalization
from .protocol_ctfCorrecion import ProtImodCtfCorrection
from .protocol_ctfEstimation import ProtImodCtfEstimation
from .protocol_ctfEstimationInteractive import ProtImodCtfEstimationInteractive

==> scipion-em-imod-3.0.8.tar.gz: scipion-em-imod-3.0.8/imod/protocols/__init__.py <==
# **************************************************************************
# *
# * Authors:     J.M. De la Rosa Trevin (delarosatrevin@scilifelab.se) [1]
# *              Federico P. de Isidro Gomez (fp.deisidro@cnb.csic.es) [1]
# *
# * [1] SciLifeLab, Stockholm University
# * [2] Centro Nacional de Biotecnologia, CSIC, Spain
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************

from .protocol_etomo import ProtImodEtomo
# from .protocol_auto3d import ProtImodAuto3D
from .protocol_xCorrPrealignment import ProtImodXcorrPrealignment
from .protocol_fiducialAlignment import ProtImodFiducialAlignment
from .protocol_tomoReconstruction import ProtImodTomoReconstruction
from .protocol_applyTransformationMatrix import ProtImodApplyTransformationMatrix
from .protocol_tsNormalization import ProtImodTSNormalization
from .protocol_tomoNormalization import ProtImodTomoNormalization
from .protocol_ctfCorrection import ProtImodCtfCorrection
from .protocol_ctfEstimation import ProtImodCtfEstimation
from .protocol_tomoProjection import ProtImodTomoProjection
from .protocol_goldBeadPicker3d import ProtImodGoldBeadPicker3d
from .protocol_xRaysEraser import ProtImodXraysEraser
# from .protocol_goldBeadEraser import ProtImodGoldBeadEraser
from .protocol_importSetOfCTFTomoSeries import ProtImodImportSetOfCtfTomoSeries
from .protocol_importSetOfTM import ProtImodImportTransformationMatrix
